<?php
/**
 * @package   OSEmbed-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2021-2022 Joomlashack.com. All rights reserved
 * @license   https://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSEmbed-Pro.
 *
 * OSEmbed-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSEmbed-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSEmbed-Pro.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Alledia\OSEmbed\Pro\Provider;

use Embera\Provider\ProviderAdapter;
use Embera\Provider\ProviderInterface;
use Embera\Url;
use Joomla\Utilities\ArrayHelper;

defined('_JEXEC') or die();

class GoogleDrive extends ProviderAdapter implements ProviderInterface
{
    /**
     * @inheritdoc
     */
    protected $endpoint = 'https://drive.google.com';

    /**
     * @inheritdoc
     */
    protected static $hosts = [
        'drive.google.com',
    ];

    /**
     * @inheritdoc
     */
    protected $httpsSupport = true;

    /**
     * @inheritdoc
     */
    protected $allowedParams = ['width', 'height', 'maxwidth', 'maxheight', 'preview'];

    protected $responsiveSupport = true;

    /**
     * @inheritDoc
     */
    public function validateUrl(Url $url)
    {
        $regex = '~http[s]?:\/\/((?:www\.)?drive\.google\.com\/file\/[a-z0-9\/\?=_\-\.\,&%\$#\@\!\+]*)~i';

        return preg_match($regex, $url);
    }

    /**
     * @inheritDoc
     */
    public function getFakeResponse()
    {
        $iframeSrc = html_entity_decode($this->url);
        $parts     = explode('?', $iframeSrc);

        $iframeSrc = array_shift($parts);
        parse_str(array_shift($parts), $iframeQuery);

        $iframeSrc = str_ireplace('/view', '/preview', $iframeSrc);

        $width = empty($iframeQuery['width'])
            ? (empty($iframeQuery['w']) ? '100%' : $iframeQuery['w'])
            : $iframeQuery['width'];

        $height = empty($iframeQuery['height'])
            ? (empty($iframeQuery['h']) ? '480' : $iframeQuery['h'])
            : $iframeQuery['height'];

        $attributes = [
            'src'                   => $iframeSrc,
            'frameborder'           => '0',
            'width'                 => $width,
            'height'                => $height,
            'allowfullscreen'       => 'true',
            'mozallowfullscreen'    => 'true',
            'webkitallowfullscreen' => 'true'
        ];

        $html = sprintf('<iframe %s></iframe>', ArrayHelper::toString($attributes));

        return [
            'type'          => $this->getProviderName() . '-file',
            'provider_name' => 'Google Drive',
            'provider_url'  => $this->endpoint,
            'title'         => 'Unknown title',
            'html'          => $html,
        ];
    }
}
