<?php
/**
 * @package   OSEmbed-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2016-2022 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSEmbed-Pro.
 *
 * OSEmbed-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSEmbed-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSEmbed-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSEmbed\Pro\Provider;

use Embera\Provider\ProviderAdapter;
use Embera\Provider\ProviderInterface;
use Embera\Url;
use Joomla\Utilities\ArrayHelper;

defined('_JEXEC') or die();

class GoogleMaps extends ProviderAdapter implements ProviderInterface
{
    /**
     * @inheritdoc
     */
    protected $endpoint = 'https://maps.google.com';

    /**
     * @inheritdoc
     */
    protected static $hosts = [
        'google.com',
        'maps.google.com'
    ];

    /**
     * @inheritdoc
     */
    protected $httpsSupport = true;

    /**
     * @inheritdoc
     */
    public function validateUrl(Url $url)
    {
        $regex = '~http[s]?:\/\/((?:www\.)?google\.com(\.[a-z]{2})?|(?:www\.)?maps\.google\.com(\.[a-z]{2})?)\/maps[/?][a-z0-9\/%,+\-_=!:@\.&*\$#?\']*~i';

        return preg_match($regex, $url);
    }

    /**
     * @inheritdoc
     */
    public function getFakeResponse()
    {
        // Check if the url is already converted to the embed format
        if (preg_match('~(maps/.*?embed|output=embed)~i', $this->url)) {
            $iframeSrc = $this->url;

        } elseif (preg_match('~@(-?[0-9\.]+,-?[0-9\.]+).+,([0-9\.]+z)~i', $this->url, $matches)) {
            // Use extracted coordinates and zoom from the url
            $query     = [
                'hl'     => 'en',
                'ie'     => 'UTF8',
                'll'     => $matches[1],
                'spn'    => $matches[1],
                't'      => 'm',
                'z'      => round($matches[2]),
                'output' => 'embed'
            ];
            $iframeSrc = 'https://maps.google.com/maps?' . http_build_query($query);

        } elseif (preg_match('~/viewer.*?mid=*([0-9a-z-_]+)~i', $this->url, $viewer)) {
            $iframeSrc = 'https://www.google.com/maps/d/embed?mid=' . $viewer[1];

        } else {
            return [];
        }

        $attributes = [
            'width'       => '600',
            'height'      => '450',
            'src'         => $iframeSrc,
            'frameborder' => '0'
        ];

        return [
            'type'          => $this->getProviderName() . '-maps',
            'provider_name' => 'Google Maps',
            'provider_url'  => 'http://maps.google.com',
            'title'         => 'Unknown title',
            'html'          => sprintf('<iframe %s></iframe>', ArrayHelper::toString($attributes)),
        ];
    }
}
